# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["CardUpdateParams"]


class CardUpdateParams(TypedDict, total=False):
    favorite: Optional[bool]

    accept_language: Annotated[str, PropertyInfo(alias="accept-language")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ...types.me import card_hire_params, card_sell_params, card_update_params
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.me.card_hire_response import CardHireResponse
from ...types.me.card_sell_response import CardSellResponse

__all__ = ["CardResource", "AsyncCardResource"]


class CardResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CardResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return CardResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CardResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return CardResourceWithStreamingResponse(self)

    def update(
        self,
        usercard_id: int,
        *,
        favorite: Optional[bool] | NotGiven = NOT_GIVEN,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Atualiza um card de um usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._put(
            f"/@me/card/{usercard_id}",
            body=maybe_transform({"favorite": favorite}, card_update_params.CardUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def hire(
        self,
        *,
        card_id: str,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CardHireResponse:
        """
        Contrata um card para um usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._post(
            "/@me/card/hire",
            body=maybe_transform({"card_id": card_id}, card_hire_params.CardHireParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CardHireResponse,
        )

    def sell(
        self,
        *,
        cards_ids: Iterable[int],
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CardSellResponse:
        """
        Vende cards de um usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._post(
            "/@me/card/sell",
            body=maybe_transform({"cards_ids": cards_ids}, card_sell_params.CardSellParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CardSellResponse,
        )

    def set_captain(
        self,
        usercard_id: int,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Atualiza um card de um usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._patch(
            f"/@me/card/{usercard_id}/captain",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncCardResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCardResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncCardResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCardResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncCardResourceWithStreamingResponse(self)

    async def update(
        self,
        usercard_id: int,
        *,
        favorite: Optional[bool] | NotGiven = NOT_GIVEN,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Atualiza um card de um usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._put(
            f"/@me/card/{usercard_id}",
            body=await async_maybe_transform({"favorite": favorite}, card_update_params.CardUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def hire(
        self,
        *,
        card_id: str,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CardHireResponse:
        """
        Contrata um card para um usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._post(
            "/@me/card/hire",
            body=await async_maybe_transform({"card_id": card_id}, card_hire_params.CardHireParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CardHireResponse,
        )

    async def sell(
        self,
        *,
        cards_ids: Iterable[int],
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> CardSellResponse:
        """
        Vende cards de um usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._post(
            "/@me/card/sell",
            body=await async_maybe_transform({"cards_ids": cards_ids}, card_sell_params.CardSellParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=CardSellResponse,
        )

    async def set_captain(
        self,
        usercard_id: int,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Atualiza um card de um usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._patch(
            f"/@me/card/{usercard_id}/captain",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class CardResourceWithRawResponse:
    def __init__(self, card: CardResource) -> None:
        self._card = card

        self.update = to_raw_response_wrapper(
            card.update,
        )
        self.hire = to_raw_response_wrapper(
            card.hire,
        )
        self.sell = to_raw_response_wrapper(
            card.sell,
        )
        self.set_captain = to_raw_response_wrapper(
            card.set_captain,
        )


class AsyncCardResourceWithRawResponse:
    def __init__(self, card: AsyncCardResource) -> None:
        self._card = card

        self.update = async_to_raw_response_wrapper(
            card.update,
        )
        self.hire = async_to_raw_response_wrapper(
            card.hire,
        )
        self.sell = async_to_raw_response_wrapper(
            card.sell,
        )
        self.set_captain = async_to_raw_response_wrapper(
            card.set_captain,
        )


class CardResourceWithStreamingResponse:
    def __init__(self, card: CardResource) -> None:
        self._card = card

        self.update = to_streamed_response_wrapper(
            card.update,
        )
        self.hire = to_streamed_response_wrapper(
            card.hire,
        )
        self.sell = to_streamed_response_wrapper(
            card.sell,
        )
        self.set_captain = to_streamed_response_wrapper(
            card.set_captain,
        )


class AsyncCardResourceWithStreamingResponse:
    def __init__(self, card: AsyncCardResource) -> None:
        self._card = card

        self.update = async_to_streamed_response_wrapper(
            card.update,
        )
        self.hire = async_to_streamed_response_wrapper(
            card.hire,
        )
        self.sell = async_to_streamed_response_wrapper(
            card.sell,
        )
        self.set_captain = async_to_streamed_response_wrapper(
            card.set_captain,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .me import (
    MeResource,
    AsyncMeResource,
    MeResourceWithRawResponse,
    AsyncMeResourceWithRawResponse,
    MeResourceWithStreamingResponse,
    AsyncMeResourceWithStreamingResponse,
)
from .user import (
    UserResource,
    AsyncUserResource,
    UserResourceWithRawResponse,
    AsyncUserResourceWithRawResponse,
    UserResourceWithStreamingResponse,
    AsyncUserResourceWithStreamingResponse,
)

__all__ = [
    "MeResource",
    "AsyncMeResource",
    "MeResourceWithRawResponse",
    "AsyncMeResourceWithRawResponse",
    "MeResourceWithStreamingResponse",
    "AsyncMeResourceWithStreamingResponse",
    "UserResource",
    "AsyncUserResource",
    "UserResourceWithRawResponse",
    "AsyncUserResourceWithRawResponse",
    "UserResourceWithStreamingResponse",
    "AsyncUserResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["CardUpParams"]


class CardUpParams(TypedDict, total=False):
    position: Required[Literal["GOL", "LD", "LE", "ZAG", "VOL", "MA", "MC", "PD", "PE", "CA"]]

    accept_language: Annotated[str, PropertyInfo(alias="accept-language")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .me import (
    MeResource,
    AsyncMeResource,
    MeResourceWithRawResponse,
    AsyncMeResourceWithRawResponse,
    MeResourceWithStreamingResponse,
    AsyncMeResourceWithStreamingResponse,
)
from .card import (
    CardResource,
    AsyncCardResource,
    CardResourceWithRawResponse,
    AsyncCardResourceWithRawResponse,
    CardResourceWithStreamingResponse,
    AsyncCardResourceWithStreamingResponse,
)
from .pack import (
    PackResource,
    AsyncPackResource,
    PackResourceWithRawResponse,
    AsyncPackResourceWithRawResponse,
    PackResourceWithStreamingResponse,
    AsyncPackResourceWithStreamingResponse,
)

__all__ = [
    "CardResource",
    "AsyncCardResource",
    "CardResourceWithRawResponse",
    "AsyncCardResourceWithRawResponse",
    "CardResourceWithStreamingResponse",
    "AsyncCardResourceWithStreamingResponse",
    "PackResource",
    "AsyncPackResource",
    "PackResourceWithRawResponse",
    "AsyncPackResourceWithRawResponse",
    "PackResourceWithStreamingResponse",
    "AsyncPackResourceWithStreamingResponse",
    "MeResource",
    "AsyncMeResource",
    "MeResourceWithRawResponse",
    "AsyncMeResourceWithRawResponse",
    "MeResourceWithStreamingResponse",
    "AsyncMeResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ConfigUpdateParams"]


class ConfigUpdateParams(TypedDict, total=False):
    auto_sell_cards_repeated: Optional[bool]

    auto_sell_less_than: Optional[int]

    accept_language: Annotated[str, PropertyInfo(alias="accept-language")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["User"]


class User(BaseModel):
    avatar_url: str

    created_at: datetime

    updated_at: datetime

    username: str

    id: Optional[str] = None

    balance: Optional[str] = None

    banned: Optional[bool] = None

    booster: Optional[bool] = None

    language: Optional[str] = None

    level: Optional[int] = None

    next_level_xp: Optional[int] = None

    xp: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .card import (
    CardResource,
    AsyncCardResource,
    CardResourceWithRawResponse,
    AsyncCardResourceWithRawResponse,
    CardResourceWithStreamingResponse,
    AsyncCardResourceWithStreamingResponse,
)
from .image import (
    ImageResource,
    AsyncImageResource,
    ImageResourceWithRawResponse,
    AsyncImageResourceWithRawResponse,
    ImageResourceWithStreamingResponse,
    AsyncImageResourceWithStreamingResponse,
)
from .lineup import (
    LineupResource,
    AsyncLineupResource,
    LineupResourceWithRawResponse,
    AsyncLineupResourceWithRawResponse,
    LineupResourceWithStreamingResponse,
    AsyncLineupResourceWithStreamingResponse,
)

__all__ = [
    "CardResource",
    "AsyncCardResource",
    "CardResourceWithRawResponse",
    "AsyncCardResourceWithRawResponse",
    "CardResourceWithStreamingResponse",
    "AsyncCardResourceWithStreamingResponse",
    "ImageResource",
    "AsyncImageResource",
    "ImageResourceWithRawResponse",
    "AsyncImageResourceWithRawResponse",
    "ImageResourceWithStreamingResponse",
    "AsyncImageResourceWithStreamingResponse",
    "LineupResource",
    "AsyncLineupResource",
    "LineupResourceWithRawResponse",
    "AsyncLineupResourceWithRawResponse",
    "LineupResourceWithStreamingResponse",
    "AsyncLineupResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import strip_not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.pack_list_response import PackListResponse

__all__ = ["PackResource", "AsyncPackResource"]


class PackResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PackResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return PackResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PackResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return PackResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PackListResponse:
        """
        Get Packs

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._get(
            "/pack",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PackListResponse,
        )


class AsyncPackResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPackResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncPackResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPackResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncPackResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PackListResponse:
        """
        Get Packs

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._get(
            "/pack",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PackListResponse,
        )


class PackResourceWithRawResponse:
    def __init__(self, pack: PackResource) -> None:
        self._pack = pack

        self.list = to_raw_response_wrapper(
            pack.list,
        )


class AsyncPackResourceWithRawResponse:
    def __init__(self, pack: AsyncPackResource) -> None:
        self._pack = pack

        self.list = async_to_raw_response_wrapper(
            pack.list,
        )


class PackResourceWithStreamingResponse:
    def __init__(self, pack: PackResource) -> None:
        self._pack = pack

        self.list = to_streamed_response_wrapper(
            pack.list,
        )


class AsyncPackResourceWithStreamingResponse:
    def __init__(self, pack: AsyncPackResource) -> None:
        self._pack = pack

        self.list = async_to_streamed_response_wrapper(
            pack.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .config_update_params import ConfigUpdateParams as ConfigUpdateParams
from .config_retrieve_response import ConfigRetrieveResponse as ConfigRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["LineupSetConfigResponse"]


class LineupSetConfigResponse(BaseModel):
    formation_id: int

    id: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from fv import Fv, AsyncFv
from fv.types import PackListResponse
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestPack:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Fv) -> None:
        pack = client.pack.list()
        assert_matches_type(PackListResponse, pack, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_with_all_params(self, client: Fv) -> None:
        pack = client.pack.list(
            accept_language="accept-language",
        )
        assert_matches_type(PackListResponse, pack, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Fv) -> None:
        response = client.pack.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pack = response.parse()
        assert_matches_type(PackListResponse, pack, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Fv) -> None:
        with client.pack.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pack = response.parse()
            assert_matches_type(PackListResponse, pack, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncPack:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncFv) -> None:
        pack = await async_client.pack.list()
        assert_matches_type(PackListResponse, pack, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncFv) -> None:
        pack = await async_client.pack.list(
            accept_language="accept-language",
        )
        assert_matches_type(PackListResponse, pack, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncFv) -> None:
        response = await async_client.pack.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        pack = await response.parse()
        assert_matches_type(PackListResponse, pack, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncFv) -> None:
        async with async_client.pack.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            pack = await response.parse()
            assert_matches_type(PackListResponse, pack, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...types.user import me_update_language_params
from ..._base_client import make_request_options
from ...types.user.user import User

__all__ = ["MeResource", "AsyncMeResource"]


class MeResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return MeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return MeResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> User:
        """
        Obter informações do usuário atual.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._get(
            "/user/@me",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=User,
        )

    def update_language(
        self,
        *,
        language: Literal["pt-BR", "en-US", "es-ES"],
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> User:
        """
        Alterar o idioma do usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._patch(
            "/user/@me/language",
            body=maybe_transform({"language": language}, me_update_language_params.MeUpdateLanguageParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=User,
        )


class AsyncMeResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncMeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncMeResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> User:
        """
        Obter informações do usuário atual.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._get(
            "/user/@me",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=User,
        )

    async def update_language(
        self,
        *,
        language: Literal["pt-BR", "en-US", "es-ES"],
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> User:
        """
        Alterar o idioma do usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._patch(
            "/user/@me/language",
            body=await async_maybe_transform({"language": language}, me_update_language_params.MeUpdateLanguageParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=User,
        )


class MeResourceWithRawResponse:
    def __init__(self, me: MeResource) -> None:
        self._me = me

        self.retrieve = to_raw_response_wrapper(
            me.retrieve,
        )
        self.update_language = to_raw_response_wrapper(
            me.update_language,
        )


class AsyncMeResourceWithRawResponse:
    def __init__(self, me: AsyncMeResource) -> None:
        self._me = me

        self.retrieve = async_to_raw_response_wrapper(
            me.retrieve,
        )
        self.update_language = async_to_raw_response_wrapper(
            me.update_language,
        )


class MeResourceWithStreamingResponse:
    def __init__(self, me: MeResource) -> None:
        self._me = me

        self.retrieve = to_streamed_response_wrapper(
            me.retrieve,
        )
        self.update_language = to_streamed_response_wrapper(
            me.update_language,
        )


class AsyncMeResourceWithStreamingResponse:
    def __init__(self, me: AsyncMeResource) -> None:
        self._me = me

        self.retrieve = async_to_streamed_response_wrapper(
            me.retrieve,
        )
        self.update_language = async_to_streamed_response_wrapper(
            me.update_language,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from fv import Fv, AsyncFv
from fv.types.me import CardHireResponse, CardSellResponse
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestCard:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: Fv) -> None:
        card = client.me.card.update(
            usercard_id=0,
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: Fv) -> None:
        card = client.me.card.update(
            usercard_id=0,
            favorite=True,
            accept_language="accept-language",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: Fv) -> None:
        response = client.me.card.with_raw_response.update(
            usercard_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = response.parse()
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: Fv) -> None:
        with client.me.card.with_streaming_response.update(
            usercard_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = response.parse()
            assert card is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_hire(self, client: Fv) -> None:
        card = client.me.card.hire(
            card_id="card_id",
        )
        assert_matches_type(CardHireResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_hire_with_all_params(self, client: Fv) -> None:
        card = client.me.card.hire(
            card_id="card_id",
            accept_language="accept-language",
        )
        assert_matches_type(CardHireResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_hire(self, client: Fv) -> None:
        response = client.me.card.with_raw_response.hire(
            card_id="card_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = response.parse()
        assert_matches_type(CardHireResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_hire(self, client: Fv) -> None:
        with client.me.card.with_streaming_response.hire(
            card_id="card_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = response.parse()
            assert_matches_type(CardHireResponse, card, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_sell(self, client: Fv) -> None:
        card = client.me.card.sell(
            cards_ids=[0],
        )
        assert_matches_type(CardSellResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_sell_with_all_params(self, client: Fv) -> None:
        card = client.me.card.sell(
            cards_ids=[0],
            accept_language="accept-language",
        )
        assert_matches_type(CardSellResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_sell(self, client: Fv) -> None:
        response = client.me.card.with_raw_response.sell(
            cards_ids=[0],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = response.parse()
        assert_matches_type(CardSellResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_sell(self, client: Fv) -> None:
        with client.me.card.with_streaming_response.sell(
            cards_ids=[0],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = response.parse()
            assert_matches_type(CardSellResponse, card, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_set_captain(self, client: Fv) -> None:
        card = client.me.card.set_captain(
            usercard_id=0,
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_method_set_captain_with_all_params(self, client: Fv) -> None:
        card = client.me.card.set_captain(
            usercard_id=0,
            accept_language="accept-language",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_set_captain(self, client: Fv) -> None:
        response = client.me.card.with_raw_response.set_captain(
            usercard_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = response.parse()
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_set_captain(self, client: Fv) -> None:
        with client.me.card.with_streaming_response.set_captain(
            usercard_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = response.parse()
            assert card is None

        assert cast(Any, response.is_closed) is True


class TestAsyncCard:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncFv) -> None:
        card = await async_client.me.card.update(
            usercard_id=0,
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncFv) -> None:
        card = await async_client.me.card.update(
            usercard_id=0,
            favorite=True,
            accept_language="accept-language",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncFv) -> None:
        response = await async_client.me.card.with_raw_response.update(
            usercard_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = await response.parse()
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncFv) -> None:
        async with async_client.me.card.with_streaming_response.update(
            usercard_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = await response.parse()
            assert card is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_hire(self, async_client: AsyncFv) -> None:
        card = await async_client.me.card.hire(
            card_id="card_id",
        )
        assert_matches_type(CardHireResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_hire_with_all_params(self, async_client: AsyncFv) -> None:
        card = await async_client.me.card.hire(
            card_id="card_id",
            accept_language="accept-language",
        )
        assert_matches_type(CardHireResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_hire(self, async_client: AsyncFv) -> None:
        response = await async_client.me.card.with_raw_response.hire(
            card_id="card_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = await response.parse()
        assert_matches_type(CardHireResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_hire(self, async_client: AsyncFv) -> None:
        async with async_client.me.card.with_streaming_response.hire(
            card_id="card_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = await response.parse()
            assert_matches_type(CardHireResponse, card, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_sell(self, async_client: AsyncFv) -> None:
        card = await async_client.me.card.sell(
            cards_ids=[0],
        )
        assert_matches_type(CardSellResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_sell_with_all_params(self, async_client: AsyncFv) -> None:
        card = await async_client.me.card.sell(
            cards_ids=[0],
            accept_language="accept-language",
        )
        assert_matches_type(CardSellResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_sell(self, async_client: AsyncFv) -> None:
        response = await async_client.me.card.with_raw_response.sell(
            cards_ids=[0],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = await response.parse()
        assert_matches_type(CardSellResponse, card, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_sell(self, async_client: AsyncFv) -> None:
        async with async_client.me.card.with_streaming_response.sell(
            cards_ids=[0],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = await response.parse()
            assert_matches_type(CardSellResponse, card, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_set_captain(self, async_client: AsyncFv) -> None:
        card = await async_client.me.card.set_captain(
            usercard_id=0,
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_set_captain_with_all_params(self, async_client: AsyncFv) -> None:
        card = await async_client.me.card.set_captain(
            usercard_id=0,
            accept_language="accept-language",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_set_captain(self, async_client: AsyncFv) -> None:
        response = await async_client.me.card.with_raw_response.set_captain(
            usercard_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = await response.parse()
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_set_captain(self, async_client: AsyncFv) -> None:
        async with async_client.me.card.with_streaming_response.set_captain(
            usercard_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = await response.parse()
            assert card is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["ProfitCalculateResponse", "Description"]


class Description(BaseModel):
    en: str

    es: str

    name: str

    pt: str

    id: Optional[int] = None


class ProfitCalculateResponse(BaseModel):
    amount: float

    description: Description

    probability: int

    id: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ..._models import BaseModel
from ..user.user import User

__all__ = ["CardSellResponse"]


class CardSellResponse(BaseModel):
    amount_claimed: float

    cards_ids: List[str]

    count_cards: int
    """Conta a quantidade de cards."""

    user: User



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.lineup import card_up_params

__all__ = ["CardResource", "AsyncCardResource"]


class CardResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CardResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return CardResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CardResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return CardResourceWithStreamingResponse(self)

    def down(
        self,
        usercard_id: int,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retira um card do time titular.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._delete(
            f"/lineup/card/{usercard_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def up(
        self,
        usercard_id: int,
        *,
        position: Literal["GOL", "LD", "LE", "ZAG", "VOL", "MA", "MC", "PD", "PE", "CA"],
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Escala um card do usuário para o time titular.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._post(
            f"/lineup/card/{usercard_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"position": position}, card_up_params.CardUpParams),
            ),
            cast_to=NoneType,
        )


class AsyncCardResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCardResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncCardResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCardResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncCardResourceWithStreamingResponse(self)

    async def down(
        self,
        usercard_id: int,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Retira um card do time titular.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._delete(
            f"/lineup/card/{usercard_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def up(
        self,
        usercard_id: int,
        *,
        position: Literal["GOL", "LD", "LE", "ZAG", "VOL", "MA", "MC", "PD", "PE", "CA"],
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Escala um card do usuário para o time titular.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._post(
            f"/lineup/card/{usercard_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"position": position}, card_up_params.CardUpParams),
            ),
            cast_to=NoneType,
        )


class CardResourceWithRawResponse:
    def __init__(self, card: CardResource) -> None:
        self._card = card

        self.down = to_raw_response_wrapper(
            card.down,
        )
        self.up = to_raw_response_wrapper(
            card.up,
        )


class AsyncCardResourceWithRawResponse:
    def __init__(self, card: AsyncCardResource) -> None:
        self._card = card

        self.down = async_to_raw_response_wrapper(
            card.down,
        )
        self.up = async_to_raw_response_wrapper(
            card.up,
        )


class CardResourceWithStreamingResponse:
    def __init__(self, card: CardResource) -> None:
        self._card = card

        self.down = to_streamed_response_wrapper(
            card.down,
        )
        self.up = to_streamed_response_wrapper(
            card.up,
        )


class AsyncCardResourceWithStreamingResponse:
    def __init__(self, card: AsyncCardResource) -> None:
        self._card = card

        self.down = async_to_streamed_response_wrapper(
            card.down,
        )
        self.up = async_to_streamed_response_wrapper(
            card.up,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["RedeemRedeemCodeResponse"]


class RedeemRedeemCodeResponse(BaseModel):
    code: str

    item_id: int

    id: Optional[int] = None

    banner: Optional[str] = None

    expire_at: Optional[datetime] = None

    limit_uses: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ...._models import BaseModel

__all__ = ["ConfigRetrieveResponse"]


class ConfigRetrieveResponse(BaseModel):
    user_id: str

    id: Optional[int] = None

    auto_sell_cards_repeated: Optional[bool] = None

    auto_sell_less_than: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .card_hire_params import CardHireParams as CardHireParams
from .card_sell_params import CardSellParams as CardSellParams
from .pack_buy_response import PackBuyResponse as PackBuyResponse
from .card_hire_response import CardHireResponse as CardHireResponse
from .card_sell_response import CardSellResponse as CardSellResponse
from .card_update_params import CardUpdateParams as CardUpdateParams
from .pack_open_response import PackOpenResponse as PackOpenResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import TypeAlias

from .._models import BaseModel

__all__ = ["PackListResponse", "PackListResponseItem"]


class PackListResponseItem(BaseModel):
    created_at: datetime

    emoji: str

    image: str

    name: str

    updated_at: datetime

    id: Optional[str] = None

    can_buy: Optional[bool] = None

    cards_amount: Optional[int] = None

    color: Optional[str] = None

    limit_per_user: Optional[int] = None

    price: Optional[str] = None


PackListResponse: TypeAlias = List[PackListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["MatchJoinRankedResponse"]


class MatchJoinRankedResponse(BaseModel):
    home_id: str

    id: Optional[int] = None

    away_id: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .me import (
    MeResource,
    AsyncMeResource,
    MeResourceWithRawResponse,
    AsyncMeResourceWithRawResponse,
    MeResourceWithStreamingResponse,
    AsyncMeResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["UserResource", "AsyncUserResource"]


class UserResource(SyncAPIResource):
    @cached_property
    def me(self) -> MeResource:
        return MeResource(self._client)

    @cached_property
    def with_raw_response(self) -> UserResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return UserResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UserResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return UserResourceWithStreamingResponse(self)


class AsyncUserResource(AsyncAPIResource):
    @cached_property
    def me(self) -> AsyncMeResource:
        return AsyncMeResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncUserResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncUserResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUserResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncUserResourceWithStreamingResponse(self)


class UserResourceWithRawResponse:
    def __init__(self, user: UserResource) -> None:
        self._user = user

    @cached_property
    def me(self) -> MeResourceWithRawResponse:
        return MeResourceWithRawResponse(self._user.me)


class AsyncUserResourceWithRawResponse:
    def __init__(self, user: AsyncUserResource) -> None:
        self._user = user

    @cached_property
    def me(self) -> AsyncMeResourceWithRawResponse:
        return AsyncMeResourceWithRawResponse(self._user.me)


class UserResourceWithStreamingResponse:
    def __init__(self, user: UserResource) -> None:
        self._user = user

    @cached_property
    def me(self) -> MeResourceWithStreamingResponse:
        return MeResourceWithStreamingResponse(self._user.me)


class AsyncUserResourceWithStreamingResponse:
    def __init__(self, user: AsyncUserResource) -> None:
        self._user = user

    @cached_property
    def me(self) -> AsyncMeResourceWithStreamingResponse:
        return AsyncMeResourceWithStreamingResponse(self._user.me)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .me import (
    MeResource,
    AsyncMeResource,
    MeResourceWithRawResponse,
    AsyncMeResourceWithRawResponse,
    MeResourceWithStreamingResponse,
    AsyncMeResourceWithStreamingResponse,
)
from .auth import (
    AuthResource,
    AsyncAuthResource,
    AuthResourceWithRawResponse,
    AsyncAuthResourceWithRawResponse,
    AuthResourceWithStreamingResponse,
    AsyncAuthResourceWithStreamingResponse,
)
from .card import (
    CardResource,
    AsyncCardResource,
    CardResourceWithRawResponse,
    AsyncCardResourceWithRawResponse,
    CardResourceWithStreamingResponse,
    AsyncCardResourceWithStreamingResponse,
)
from .pack import (
    PackResource,
    AsyncPackResource,
    PackResourceWithRawResponse,
    AsyncPackResourceWithRawResponse,
    PackResourceWithStreamingResponse,
    AsyncPackResourceWithStreamingResponse,
)
from .user import (
    UserResource,
    AsyncUserResource,
    UserResourceWithRawResponse,
    AsyncUserResourceWithRawResponse,
    UserResourceWithStreamingResponse,
    AsyncUserResourceWithStreamingResponse,
)
from .match import (
    MatchResource,
    AsyncMatchResource,
    MatchResourceWithRawResponse,
    AsyncMatchResourceWithRawResponse,
    MatchResourceWithStreamingResponse,
    AsyncMatchResourceWithStreamingResponse,
)
from .lineup import (
    LineupResource,
    AsyncLineupResource,
    LineupResourceWithRawResponse,
    AsyncLineupResourceWithRawResponse,
    LineupResourceWithStreamingResponse,
    AsyncLineupResourceWithStreamingResponse,
)
from .profit import (
    ProfitResource,
    AsyncProfitResource,
    ProfitResourceWithRawResponse,
    AsyncProfitResourceWithRawResponse,
    ProfitResourceWithStreamingResponse,
    AsyncProfitResourceWithStreamingResponse,
)
from .redeem import (
    RedeemResource,
    AsyncRedeemResource,
    RedeemResourceWithRawResponse,
    AsyncRedeemResourceWithRawResponse,
    RedeemResourceWithStreamingResponse,
    AsyncRedeemResourceWithStreamingResponse,
)
from .userinventory import (
    UserinventoryResource,
    AsyncUserinventoryResource,
    UserinventoryResourceWithRawResponse,
    AsyncUserinventoryResourceWithRawResponse,
    UserinventoryResourceWithStreamingResponse,
    AsyncUserinventoryResourceWithStreamingResponse,
)

__all__ = [
    "ProfitResource",
    "AsyncProfitResource",
    "ProfitResourceWithRawResponse",
    "AsyncProfitResourceWithRawResponse",
    "ProfitResourceWithStreamingResponse",
    "AsyncProfitResourceWithStreamingResponse",
    "PackResource",
    "AsyncPackResource",
    "PackResourceWithRawResponse",
    "AsyncPackResourceWithRawResponse",
    "PackResourceWithStreamingResponse",
    "AsyncPackResourceWithStreamingResponse",
    "MeResource",
    "AsyncMeResource",
    "MeResourceWithRawResponse",
    "AsyncMeResourceWithRawResponse",
    "MeResourceWithStreamingResponse",
    "AsyncMeResourceWithStreamingResponse",
    "RedeemResource",
    "AsyncRedeemResource",
    "RedeemResourceWithRawResponse",
    "AsyncRedeemResourceWithRawResponse",
    "RedeemResourceWithStreamingResponse",
    "AsyncRedeemResourceWithStreamingResponse",
    "LineupResource",
    "AsyncLineupResource",
    "LineupResourceWithRawResponse",
    "AsyncLineupResourceWithRawResponse",
    "LineupResourceWithStreamingResponse",
    "AsyncLineupResourceWithStreamingResponse",
    "UserResource",
    "AsyncUserResource",
    "UserResourceWithRawResponse",
    "AsyncUserResourceWithRawResponse",
    "UserResourceWithStreamingResponse",
    "AsyncUserResourceWithStreamingResponse",
    "CardResource",
    "AsyncCardResource",
    "CardResourceWithRawResponse",
    "AsyncCardResourceWithRawResponse",
    "CardResourceWithStreamingResponse",
    "AsyncCardResourceWithStreamingResponse",
    "MatchResource",
    "AsyncMatchResource",
    "MatchResourceWithRawResponse",
    "AsyncMatchResourceWithRawResponse",
    "MatchResourceWithStreamingResponse",
    "AsyncMatchResourceWithStreamingResponse",
    "UserinventoryResource",
    "AsyncUserinventoryResource",
    "UserinventoryResourceWithRawResponse",
    "AsyncUserinventoryResourceWithRawResponse",
    "UserinventoryResourceWithStreamingResponse",
    "AsyncUserinventoryResourceWithStreamingResponse",
    "AuthResource",
    "AsyncAuthResource",
    "AuthResourceWithRawResponse",
    "AsyncAuthResourceWithRawResponse",
    "AuthResourceWithStreamingResponse",
    "AsyncAuthResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .pack import (
    PackResource,
    AsyncPackResource,
    PackResourceWithRawResponse,
    AsyncPackResourceWithRawResponse,
    PackResourceWithStreamingResponse,
    AsyncPackResourceWithStreamingResponse,
)
from .config import (
    ConfigResource,
    AsyncConfigResource,
    ConfigResourceWithRawResponse,
    AsyncConfigResourceWithRawResponse,
    ConfigResourceWithStreamingResponse,
    AsyncConfigResourceWithStreamingResponse,
)

__all__ = [
    "ConfigResource",
    "AsyncConfigResource",
    "ConfigResourceWithRawResponse",
    "AsyncConfigResourceWithRawResponse",
    "ConfigResourceWithStreamingResponse",
    "AsyncConfigResourceWithStreamingResponse",
    "PackResource",
    "AsyncPackResource",
    "PackResourceWithRawResponse",
    "AsyncPackResourceWithRawResponse",
    "PackResourceWithStreamingResponse",
    "AsyncPackResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .card import (
    CardResource,
    AsyncCardResource,
    CardResourceWithRawResponse,
    AsyncCardResourceWithRawResponse,
    CardResourceWithStreamingResponse,
    AsyncCardResourceWithStreamingResponse,
)
from .image import (
    ImageResource,
    AsyncImageResource,
    ImageResourceWithRawResponse,
    AsyncImageResourceWithRawResponse,
    ImageResourceWithStreamingResponse,
    AsyncImageResourceWithStreamingResponse,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import strip_not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.lineup_set_config_response import LineupSetConfigResponse

__all__ = ["LineupResource", "AsyncLineupResource"]


class LineupResource(SyncAPIResource):
    @cached_property
    def card(self) -> CardResource:
        return CardResource(self._client)

    @cached_property
    def image(self) -> ImageResource:
        return ImageResource(self._client)

    @cached_property
    def with_raw_response(self) -> LineupResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return LineupResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LineupResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return LineupResourceWithStreamingResponse(self)

    def set_config(
        self,
        formation_id: str,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LineupSetConfigResponse:
        """
        Seta a formação do time titular.

        Se o usuário já tiver uma formação configurada, ela será atualizada.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not formation_id:
            raise ValueError(f"Expected a non-empty value for `formation_id` but received {formation_id!r}")
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._post(
            f"/lineup/formation/{formation_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LineupSetConfigResponse,
        )


class AsyncLineupResource(AsyncAPIResource):
    @cached_property
    def card(self) -> AsyncCardResource:
        return AsyncCardResource(self._client)

    @cached_property
    def image(self) -> AsyncImageResource:
        return AsyncImageResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncLineupResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncLineupResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLineupResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncLineupResourceWithStreamingResponse(self)

    async def set_config(
        self,
        formation_id: str,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LineupSetConfigResponse:
        """
        Seta a formação do time titular.

        Se o usuário já tiver uma formação configurada, ela será atualizada.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not formation_id:
            raise ValueError(f"Expected a non-empty value for `formation_id` but received {formation_id!r}")
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._post(
            f"/lineup/formation/{formation_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LineupSetConfigResponse,
        )


class LineupResourceWithRawResponse:
    def __init__(self, lineup: LineupResource) -> None:
        self._lineup = lineup

        self.set_config = to_raw_response_wrapper(
            lineup.set_config,
        )

    @cached_property
    def card(self) -> CardResourceWithRawResponse:
        return CardResourceWithRawResponse(self._lineup.card)

    @cached_property
    def image(self) -> ImageResourceWithRawResponse:
        return ImageResourceWithRawResponse(self._lineup.image)


class AsyncLineupResourceWithRawResponse:
    def __init__(self, lineup: AsyncLineupResource) -> None:
        self._lineup = lineup

        self.set_config = async_to_raw_response_wrapper(
            lineup.set_config,
        )

    @cached_property
    def card(self) -> AsyncCardResourceWithRawResponse:
        return AsyncCardResourceWithRawResponse(self._lineup.card)

    @cached_property
    def image(self) -> AsyncImageResourceWithRawResponse:
        return AsyncImageResourceWithRawResponse(self._lineup.image)


class LineupResourceWithStreamingResponse:
    def __init__(self, lineup: LineupResource) -> None:
        self._lineup = lineup

        self.set_config = to_streamed_response_wrapper(
            lineup.set_config,
        )

    @cached_property
    def card(self) -> CardResourceWithStreamingResponse:
        return CardResourceWithStreamingResponse(self._lineup.card)

    @cached_property
    def image(self) -> ImageResourceWithStreamingResponse:
        return ImageResourceWithStreamingResponse(self._lineup.image)


class AsyncLineupResourceWithStreamingResponse:
    def __init__(self, lineup: AsyncLineupResource) -> None:
        self._lineup = lineup

        self.set_config = async_to_streamed_response_wrapper(
            lineup.set_config,
        )

    @cached_property
    def card(self) -> AsyncCardResourceWithStreamingResponse:
        return AsyncCardResourceWithStreamingResponse(self._lineup.card)

    @cached_property
    def image(self) -> AsyncImageResourceWithStreamingResponse:
        return AsyncImageResourceWithStreamingResponse(self._lineup.image)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["RedeemRedeemCodeParams"]


class RedeemRedeemCodeParams(TypedDict, total=False):
    code: Required[str]

    accept_language: Annotated[str, PropertyInfo(alias="accept-language")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ..._models import BaseModel
from ..user.user import User

__all__ = ["CardHireResponse", "Card"]


class Card(BaseModel):
    attack: int

    collection_id: int

    created_at: datetime

    creation: int

    defense: int

    name: str

    nationality_id: int

    overall: int

    position: str

    stats_id: int

    team_id: int

    updated_at: datetime

    id: Optional[str] = None

    background_id: Optional[int] = None

    blocked_contract: Optional[bool] = None

    buy_price: Optional[str] = None

    image: Optional[str] = None

    price: Optional[str] = None

    secundary_positions: Optional[List[object]] = None

    sell_price: Optional[str] = None


class CardHireResponse(BaseModel):
    card: Card

    user: User



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from fv import Fv, AsyncFv
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestImage:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get(self, client: Fv) -> None:
        image = client.lineup.image.get()
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_with_all_params(self, client: Fv) -> None:
        image = client.lineup.image.get(
            accept_language="accept-language",
        )
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get(self, client: Fv) -> None:
        response = client.lineup.image.with_raw_response.get()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        image = response.parse()
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get(self, client: Fv) -> None:
        with client.lineup.image.with_streaming_response.get() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            image = response.parse()
            assert_matches_type(object, image, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_by_user_id(self, client: Fv) -> None:
        image = client.lineup.image.get_by_user_id(
            user_id="user_id",
        )
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_by_user_id_with_all_params(self, client: Fv) -> None:
        image = client.lineup.image.get_by_user_id(
            user_id="user_id",
            accept_language="accept-language",
        )
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_by_user_id(self, client: Fv) -> None:
        response = client.lineup.image.with_raw_response.get_by_user_id(
            user_id="user_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        image = response.parse()
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_by_user_id(self, client: Fv) -> None:
        with client.lineup.image.with_streaming_response.get_by_user_id(
            user_id="user_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            image = response.parse()
            assert_matches_type(object, image, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_get_by_user_id(self, client: Fv) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `user_id` but received ''"):
            client.lineup.image.with_raw_response.get_by_user_id(
                user_id="",
            )


class TestAsyncImage:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_get(self, async_client: AsyncFv) -> None:
        image = await async_client.lineup.image.get()
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_with_all_params(self, async_client: AsyncFv) -> None:
        image = await async_client.lineup.image.get(
            accept_language="accept-language",
        )
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get(self, async_client: AsyncFv) -> None:
        response = await async_client.lineup.image.with_raw_response.get()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        image = await response.parse()
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get(self, async_client: AsyncFv) -> None:
        async with async_client.lineup.image.with_streaming_response.get() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            image = await response.parse()
            assert_matches_type(object, image, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_by_user_id(self, async_client: AsyncFv) -> None:
        image = await async_client.lineup.image.get_by_user_id(
            user_id="user_id",
        )
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_by_user_id_with_all_params(self, async_client: AsyncFv) -> None:
        image = await async_client.lineup.image.get_by_user_id(
            user_id="user_id",
            accept_language="accept-language",
        )
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_by_user_id(self, async_client: AsyncFv) -> None:
        response = await async_client.lineup.image.with_raw_response.get_by_user_id(
            user_id="user_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        image = await response.parse()
        assert_matches_type(object, image, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_by_user_id(self, async_client: AsyncFv) -> None:
        async with async_client.lineup.image.with_streaming_response.get_by_user_id(
            user_id="user_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            image = await response.parse()
            assert_matches_type(object, image, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_get_by_user_id(self, async_client: AsyncFv) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `user_id` but received ''"):
            await async_client.lineup.image.with_raw_response.get_by_user_id(
                user_id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["PackBuyResponse"]


class PackBuyResponse(BaseModel):
    pack_id: str

    user_id: str

    id: Optional[int] = None

    quant: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["MeUpdateLanguageParams"]


class MeUpdateLanguageParams(TypedDict, total=False):
    language: Required[Literal["pt-BR", "en-US", "es-ES"]]

    accept_language: Annotated[str, PropertyInfo(alias="accept-language")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["UserinventoryRedeemResponse"]


class UserinventoryRedeemResponse(BaseModel):
    item_id: str

    item_type: str

    id: Optional[int] = None

    display_name_id: Optional[int] = None

    image_url: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from fv import Fv, AsyncFv

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestCard:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_down(self, client: Fv) -> None:
        card = client.lineup.card.down(
            usercard_id=0,
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_method_down_with_all_params(self, client: Fv) -> None:
        card = client.lineup.card.down(
            usercard_id=0,
            accept_language="accept-language",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_down(self, client: Fv) -> None:
        response = client.lineup.card.with_raw_response.down(
            usercard_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = response.parse()
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_down(self, client: Fv) -> None:
        with client.lineup.card.with_streaming_response.down(
            usercard_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = response.parse()
            assert card is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_up(self, client: Fv) -> None:
        card = client.lineup.card.up(
            usercard_id=0,
            position="GOL",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_method_up_with_all_params(self, client: Fv) -> None:
        card = client.lineup.card.up(
            usercard_id=0,
            position="GOL",
            accept_language="accept-language",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_up(self, client: Fv) -> None:
        response = client.lineup.card.with_raw_response.up(
            usercard_id=0,
            position="GOL",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = response.parse()
        assert card is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_up(self, client: Fv) -> None:
        with client.lineup.card.with_streaming_response.up(
            usercard_id=0,
            position="GOL",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = response.parse()
            assert card is None

        assert cast(Any, response.is_closed) is True


class TestAsyncCard:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_down(self, async_client: AsyncFv) -> None:
        card = await async_client.lineup.card.down(
            usercard_id=0,
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_down_with_all_params(self, async_client: AsyncFv) -> None:
        card = await async_client.lineup.card.down(
            usercard_id=0,
            accept_language="accept-language",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_down(self, async_client: AsyncFv) -> None:
        response = await async_client.lineup.card.with_raw_response.down(
            usercard_id=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = await response.parse()
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_down(self, async_client: AsyncFv) -> None:
        async with async_client.lineup.card.with_streaming_response.down(
            usercard_id=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = await response.parse()
            assert card is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_up(self, async_client: AsyncFv) -> None:
        card = await async_client.lineup.card.up(
            usercard_id=0,
            position="GOL",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_method_up_with_all_params(self, async_client: AsyncFv) -> None:
        card = await async_client.lineup.card.up(
            usercard_id=0,
            position="GOL",
            accept_language="accept-language",
        )
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_up(self, async_client: AsyncFv) -> None:
        response = await async_client.lineup.card.with_raw_response.up(
            usercard_id=0,
            position="GOL",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        card = await response.parse()
        assert card is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_up(self, async_client: AsyncFv) -> None:
        async with async_client.lineup.card.with_streaming_response.up(
            usercard_id=0,
            position="GOL",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            card = await response.parse()
            assert card is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from ..._models import BaseModel

__all__ = ["PackOpenResponse", "PackOpenResponseItem"]


class PackOpenResponseItem(BaseModel):
    card_id: str

    rule: Optional[Literal["auto_sell_less_than", "auto_sell_cards_repeated"]] = None

    sold: bool

    usercard_id: int

    sold_value: Optional[float] = None


PackOpenResponse: TypeAlias = List[PackOpenResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from ...._utils import maybe_transform, strip_not_given, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.me.pack import config_update_params
from ....types.me.pack.config_retrieve_response import ConfigRetrieveResponse

__all__ = ["ConfigResource", "AsyncConfigResource"]


class ConfigResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ConfigResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return ConfigResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ConfigResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return ConfigResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ConfigRetrieveResponse:
        """
        Retorna as configurações de packs do usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._get(
            "/@me/pack/config",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConfigRetrieveResponse,
        )

    def update(
        self,
        *,
        auto_sell_cards_repeated: Optional[bool] | NotGiven = NOT_GIVEN,
        auto_sell_less_than: Optional[int] | NotGiven = NOT_GIVEN,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Atualiza as configurações de packs do usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._put(
            "/@me/pack/config",
            body=maybe_transform(
                {
                    "auto_sell_cards_repeated": auto_sell_cards_repeated,
                    "auto_sell_less_than": auto_sell_less_than,
                },
                config_update_params.ConfigUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncConfigResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncConfigResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncConfigResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncConfigResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncConfigResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ConfigRetrieveResponse:
        """
        Retorna as configurações de packs do usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._get(
            "/@me/pack/config",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ConfigRetrieveResponse,
        )

    async def update(
        self,
        *,
        auto_sell_cards_repeated: Optional[bool] | NotGiven = NOT_GIVEN,
        auto_sell_less_than: Optional[int] | NotGiven = NOT_GIVEN,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Atualiza as configurações de packs do usuário.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._put(
            "/@me/pack/config",
            body=await async_maybe_transform(
                {
                    "auto_sell_cards_repeated": auto_sell_cards_repeated,
                    "auto_sell_less_than": auto_sell_less_than,
                },
                config_update_params.ConfigUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class ConfigResourceWithRawResponse:
    def __init__(self, config: ConfigResource) -> None:
        self._config = config

        self.retrieve = to_raw_response_wrapper(
            config.retrieve,
        )
        self.update = to_raw_response_wrapper(
            config.update,
        )


class AsyncConfigResourceWithRawResponse:
    def __init__(self, config: AsyncConfigResource) -> None:
        self._config = config

        self.retrieve = async_to_raw_response_wrapper(
            config.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            config.update,
        )


class ConfigResourceWithStreamingResponse:
    def __init__(self, config: ConfigResource) -> None:
        self._config = config

        self.retrieve = to_streamed_response_wrapper(
            config.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            config.update,
        )


class AsyncConfigResourceWithStreamingResponse:
    def __init__(self, config: AsyncConfigResource) -> None:
        self._config = config

        self.retrieve = async_to_streamed_response_wrapper(
            config.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            config.update,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import auth_login_discord_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, strip_not_given, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.auth_login_discord_response import AuthLoginDiscordResponse

__all__ = ["AuthResource", "AsyncAuthResource"]


class AuthResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AuthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AuthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AuthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AuthResourceWithStreamingResponse(self)

    def login_discord(
        self,
        *,
        code: str,
        origin: str,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AuthLoginDiscordResponse:
        """
        Login via Discord.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._post(
            "/auth/discord",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "code": code,
                        "origin": origin,
                    },
                    auth_login_discord_params.AuthLoginDiscordParams,
                ),
            ),
            cast_to=AuthLoginDiscordResponse,
        )


class AsyncAuthResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncAuthResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncAuthResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAuthResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncAuthResourceWithStreamingResponse(self)

    async def login_discord(
        self,
        *,
        code: str,
        origin: str,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> AuthLoginDiscordResponse:
        """
        Login via Discord.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._post(
            "/auth/discord",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "code": code,
                        "origin": origin,
                    },
                    auth_login_discord_params.AuthLoginDiscordParams,
                ),
            ),
            cast_to=AuthLoginDiscordResponse,
        )


class AuthResourceWithRawResponse:
    def __init__(self, auth: AuthResource) -> None:
        self._auth = auth

        self.login_discord = to_raw_response_wrapper(
            auth.login_discord,
        )


class AsyncAuthResourceWithRawResponse:
    def __init__(self, auth: AsyncAuthResource) -> None:
        self._auth = auth

        self.login_discord = async_to_raw_response_wrapper(
            auth.login_discord,
        )


class AuthResourceWithStreamingResponse:
    def __init__(self, auth: AuthResource) -> None:
        self._auth = auth

        self.login_discord = to_streamed_response_wrapper(
            auth.login_discord,
        )


class AsyncAuthResourceWithStreamingResponse:
    def __init__(self, auth: AsyncAuthResource) -> None:
        self._auth = auth

        self.login_discord = async_to_streamed_response_wrapper(
            auth.login_discord,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .pack_list_response import PackListResponse as PackListResponse
from .auth_login_discord_params import AuthLoginDiscordParams as AuthLoginDiscordParams
from .profit_calculate_response import ProfitCalculateResponse as ProfitCalculateResponse
from .redeem_redeem_code_params import RedeemRedeemCodeParams as RedeemRedeemCodeParams
from .lineup_set_config_response import LineupSetConfigResponse as LineupSetConfigResponse
from .match_join_ranked_response import MatchJoinRankedResponse as MatchJoinRankedResponse
from .auth_login_discord_response import AuthLoginDiscordResponse as AuthLoginDiscordResponse
from .redeem_redeem_code_response import RedeemRedeemCodeResponse as RedeemRedeemCodeResponse
from .userinventory_redeem_response import UserinventoryRedeemResponse as UserinventoryRedeemResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .card import (
    CardResource,
    AsyncCardResource,
    CardResourceWithRawResponse,
    AsyncCardResourceWithRawResponse,
    CardResourceWithStreamingResponse,
    AsyncCardResourceWithStreamingResponse,
)
from ..._compat import cached_property
from .pack.pack import (
    PackResource,
    AsyncPackResource,
    PackResourceWithRawResponse,
    AsyncPackResourceWithRawResponse,
    PackResourceWithStreamingResponse,
    AsyncPackResourceWithStreamingResponse,
)
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["MeResource", "AsyncMeResource"]


class MeResource(SyncAPIResource):
    @cached_property
    def card(self) -> CardResource:
        return CardResource(self._client)

    @cached_property
    def pack(self) -> PackResource:
        return PackResource(self._client)

    @cached_property
    def with_raw_response(self) -> MeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return MeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return MeResourceWithStreamingResponse(self)


class AsyncMeResource(AsyncAPIResource):
    @cached_property
    def card(self) -> AsyncCardResource:
        return AsyncCardResource(self._client)

    @cached_property
    def pack(self) -> AsyncPackResource:
        return AsyncPackResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncMeResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncMeResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMeResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncMeResourceWithStreamingResponse(self)


class MeResourceWithRawResponse:
    def __init__(self, me: MeResource) -> None:
        self._me = me

    @cached_property
    def card(self) -> CardResourceWithRawResponse:
        return CardResourceWithRawResponse(self._me.card)

    @cached_property
    def pack(self) -> PackResourceWithRawResponse:
        return PackResourceWithRawResponse(self._me.pack)


class AsyncMeResourceWithRawResponse:
    def __init__(self, me: AsyncMeResource) -> None:
        self._me = me

    @cached_property
    def card(self) -> AsyncCardResourceWithRawResponse:
        return AsyncCardResourceWithRawResponse(self._me.card)

    @cached_property
    def pack(self) -> AsyncPackResourceWithRawResponse:
        return AsyncPackResourceWithRawResponse(self._me.pack)


class MeResourceWithStreamingResponse:
    def __init__(self, me: MeResource) -> None:
        self._me = me

    @cached_property
    def card(self) -> CardResourceWithStreamingResponse:
        return CardResourceWithStreamingResponse(self._me.card)

    @cached_property
    def pack(self) -> PackResourceWithStreamingResponse:
        return PackResourceWithStreamingResponse(self._me.pack)


class AsyncMeResourceWithStreamingResponse:
    def __init__(self, me: AsyncMeResource) -> None:
        self._me = me

    @cached_property
    def card(self) -> AsyncCardResourceWithStreamingResponse:
        return AsyncCardResourceWithStreamingResponse(self._me.card)

    @cached_property
    def pack(self) -> AsyncPackResourceWithStreamingResponse:
        return AsyncPackResourceWithStreamingResponse(self._me.pack)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import strip_not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["ImageResource", "AsyncImageResource"]


class ImageResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ImageResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return ImageResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ImageResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return ImageResourceWithStreamingResponse(self)

    def get(
        self,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Retorna a imagem do time titular.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._get(
            "/lineup/image",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def get_by_user_id(
        self,
        user_id: str,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Retorna a imagem do time titular.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return self._get(
            f"/lineup/image/{user_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncImageResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncImageResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#accessing-raw-response-data-eg-headers
        """
        return AsyncImageResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncImageResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/victorgabrieldeon/fv-api#with_streaming_response
        """
        return AsyncImageResourceWithStreamingResponse(self)

    async def get(
        self,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Retorna a imagem do time titular.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._get(
            "/lineup/image",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    async def get_by_user_id(
        self,
        user_id: str,
        *,
        accept_language: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Retorna a imagem do time titular.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        extra_headers = {**strip_not_given({"accept-language": accept_language}), **(extra_headers or {})}
        return await self._get(
            f"/lineup/image/{user_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class ImageResourceWithRawResponse:
    def __init__(self, image: ImageResource) -> None:
        self._image = image

        self.get = to_raw_response_wrapper(
            image.get,
        )
        self.get_by_user_id = to_raw_response_wrapper(
            image.get_by_user_id,
        )


class AsyncImageResourceWithRawResponse:
    def __init__(self, image: AsyncImageResource) -> None:
        self._image = image

        self.get = async_to_raw_response_wrapper(
            image.get,
        )
        self.get_by_user_id = async_to_raw_response_wrapper(
            image.get_by_user_id,
        )


class ImageResourceWithStreamingResponse:
    def __init__(self, image: ImageResource) -> None:
        self._image = image

        self.get = to_streamed_response_wrapper(
            image.get,
        )
        self.get_by_user_id = to_streamed_response_wrapper(
            image.get_by_user_id,
        )


class AsyncImageResourceWithStreamingResponse:
    def __init__(self, image: AsyncImageResource) -> None:
        self._image = image

        self.get = async_to_streamed_response_wrapper(
            image.get,
        )
        self.get_by_user_id = async_to_streamed_response_wrapper(
            image.get_by_user_id,
        )
